@@ -7,14 +7,13 @@ class MemberFinder(AbstractFinder):
     Cache based Member finder
     """
 
-    search_fields = ['name', 'name_hira']
-
-    def __init__(self, members=None, **kwargs):
+    def __init__(self, members=None, search_fields=None, **kwargs):
+        super().__init__(search_fields or ['name', 'name_hira'])
         if members:
             self.members = members
         else:
             client = GraphQLClient(**kwargs)
             self.members = client.get_all_members(['id'] + self.search_fields)
 
-    def find(self, text):
-        return list(filter(lambda x: self.match(x, text), self.members))
+    def find(self, text, exact_match=False):
+        return list(filter(lambda x: self.match(x, text, exact_match), self.members))
